# Construct and display the mult response set information in the current dataset
# Note that this output is all in Unicode.  (That is the encoding of the CreateXPathDictionary
# api, but it could easily be transcoded into a code page if needed.)

# This illustrates the use of the spss.CreateXPathDictionary api, which produces the entire dictionary,
# and the Python xml processing facilities.
# An alternative way of processing this information is using XPath via the spss.EvaluateXPath api.

from xml.sax.handler import ContentHandler
import xml.sax
import random
import spss

# This class extracts the multiple response sets from the variable dictionary using SAX.
# The StartElement method of the content handler sees every element in the variable dictionary.
# It selects only multiple response information and stores the sets and their attributes as they
# appear.  All of the MR elements are singletons except for the variable list.

# These are later retrieved from the handler object.

# It may be helpful in working through this example to look at actual dictionary xml.  You can
# produce a file of this using something like
#   spss.GetXmlUtf16(tag, filespec)
# where tag identifies the output of spss.CreateXPathDictionary in the workspace

__author__ =  'spss'
__version__=  '1.0.0'

# History
#   03-Feb-2006 Initial version


class countHandler(ContentHandler):
    def __init__(self):
        self.mrsets = {}
    def startElement(self, name, attr):
        if name.startswith(u'multipleResponseSet'):
            theAttr = attr.has_key(u'name') and attr.getValue(u'name') or attr.getValue(u'value')
            if name == "multipleResponseSet":
                self.mrsets[theAttr] = {}
                self.currentset = theAttr
                self.mrsets[self.currentset][u'multipleResponseSetVariable'] = []
            elif name == u'multipleResponseSetVariable':
                self.mrsets[self.currentset][name].append(theAttr)
            else:
                self.mrsets[self.currentset][name] = theAttr     #todo: appends

# illustrate usage by constructing a Python dictionary of the SPSS mr set information            

def Display():       
    handler = countHandler()
    tag = "D"+ str(random.uniform(0,1))
    spss.CreateXPathDictionary(tag)

    # Retrieve and parse the dictionary
    xml.sax.parseString(spss.GetXmlUtf16(tag),handler)
    spss.DeleteXPathHandle(tag)

    #display the set information using the names from the SPSS dictionary schema.

    for mrset in sorted(handler.mrsets):
        print "\nmultiple response set:", mrset
        for item in handler.mrsets[mrset]:
            print "\t",item,":", handler.mrsets[mrset][item]
